@@ -4,15 +4,23 @@ __file="${__dir}/$(basename "${BASH_SOURCE[0]}")"
 __base="$(basename ${__file} .sh)"
 __root="$(cd "$(dirname "${__dir}")" && pwd)" # <-- change this as it depends on your app
 
+BINPREFIX=""
 BIN=cloud-torrent
+
+if [[ -d ${BINLOCATION} ]]; then
+	BINPREFIX=${BINLOCATION}/
+fi
+
 GITVER=$(git describe --tags)
 
 OS=""
 ARCH=""
 SUFFIX=""
+OSSUFFIX=""
 PKGCMD=
 NOSTATIC=
 CGO=1
+STASHED=0
 
 for arg in "$@"; do
 case $arg in
@@ -27,7 +35,11 @@ case $arg in
 		;;
 	windows)
 		OS=windows
-		SUFFIX=.exe
+		OSSUFFIX=.exe
+		;;
+	darwin)
+		OS=darwin
+		ARCH=amd64
 		;;
 	xz)
 		PKGCMD=xz
@@ -54,24 +66,14 @@ if [[ -z $ARCH ]]; then
   ARCH=$(go env GOARCH)
 fi
 
-if [[ -z $NOSTATIC ]]; then
-	pushd $__dir/../static
-	sh generate.sh
-	popd
-fi
-
 pushd $__dir/..
-BINFILE=${BIN}_${OS}_${ARCH}${SUFFIX} 
+BINFILE=${BINPREFIX}${BIN}_${OS}_${ARCH}${SUFFIX}${OSSUFFIX}
 CGO_ENABLED=$CGO GOARCH=$ARCH GOOS=$OS go build -o ${BINFILE} -trimpath -ldflags "-s -w -X main.VERSION=$GITVER"
 if [[ ! -f ${BINFILE} ]]; then
   echo "Build failed. Check with error message above."
   exit 1
 fi
 
-if [[ -z $NOSTATIC ]]; then
-	git checkout HEAD -- static/*
-fi
-
 if [[ ! -z $PKGCMD ]]; then
   ${PKGCMD} -v -9 ${BINFILE}
 fi
