@@ -1,14 +1,18 @@
 /* globals app */
 
-app.controller("TorrentsController", function ($scope, $rootScope, api) {
+app.controller("TorrentsController", function ($scope, $rootScope, api, reqinfo, reqerr) {
   $rootScope.torrents = $scope;
 
   $scope.submitTorrent = function (action, t) {
-    api.torrent([action, t.InfoHash].join(":"));
+    api.torrent([action, t.InfoHash].join(":")).then(function (xhr) {
+      console.log(`${action}:${xhr.data}`);
+    }).finally(function () {
+      t.showSubBtns = false;
+    });
   };
 
   $scope.submitFile = function (action, t, f) {
-    api.file([action, t.InfoHash, f.Path].join(":"));
+    api.file([action, t.InfoHash, f.Path].join(":")).then(reqinfo, reqerr);
   };
 
   $scope.downloading = function (f) {
@@ -34,6 +38,14 @@ app.controller("TorrentsController", function ($scope, $rootScope, api) {
     return false;
   };
 
+  $scope.onDeleteBtnClick = function (t) {
+    if (!$rootScope.state.UseQueue) {
+      $scope.submitTorrent("delete", t);
+      return
+    }
+    t.showSubBtns = !(t.showSubBtns);
+  }
+
   $scope.$expanded = true;
   $scope.section_expanded_toggle = function () {
     $scope.$expanded = !$scope.$expanded;
